{% load static simpletags %}
<script type="text/javascript" src="{% static 'admin/simpleui-x/js/vue.min.js' %}?_={% get_version %}"></script>

<script type="text/javascript" src="{% static 'admin/simpleui-x/elementui/index.js' %}?_={% get_version %}"></script>