{#{% extends "admin/base_site.html" %}#}
{% load i18n %}
{##}
{#{% block breadcrumbs %}<div class="breadcrumbs"><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></div>{% endblock %}#}
{##}
{#{% block content %}#}
{##}
{#<p>{% trans "Thanks for spending some quality time with the Web site today." %}</p>#}
{##}
{#<p><a href="{% url 'admin:index' %}">{% trans 'Log in again' %}</a></p>#}
{##}
{#{% endblock %}#}

<html>
<head>
    <meta http-equiv="refresh" content="0;url={% url 'admin:login' %}">
</head>
<body>
<p><a href="{% url 'admin:index' %}">{% trans 'Log in again' %}</a></p>
</body>
</html>