{% extends "admin/base_site.html" %}
{% load i18n admin_urls %}

{% block breadcrumbs %}
    <div class="breadcrumbs">
        <a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
        &rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
        &rsaquo; <a href="{% url opts|admin_urlname:'changelist' %}">{{ module_name }}</a>
        &rsaquo; <a
            href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">{{ object|truncatewords:"18" }}</a>
        &rsaquo; {% trans 'History' %}
    </div>
{% endblock %}

{% block content %}
    <style>
        body, #container {
            background: #FFF!important;
        }
    </style>
    <div id="content-main">
        <div class="module">

            {% if action_list %}
                <table id="change-history" class="layui-table">
                    <thead>
                    <tr>
                        <th scope="col">{% trans 'Date/time' %}</th>
                        <th scope="col">{% trans 'User' %}</th>
                        <th scope="col">{% trans 'Action' %}</th>
                    </tr>
                    </thead>
                    <tbody>
                    {% for action in action_list %}
                        <tr>
                            <th scope="row">{{ action.action_time|date:"DATETIME_FORMAT" }}</th>
                            <td>{{ action.user.get_username }}{% if action.user.get_full_name %} (
                                {{ action.user.get_full_name }}){% endif %}</td>
                            <td>{{ action.get_change_message }}</td>
                        </tr>
                    {% endfor %}
                    </tbody>
                </table>
            {% else %}
                <p>{% trans "This object doesn't have a change history. It probably wasn't added via this admin site." %}</p>
            {% endif %}
        </div>
    </div>

{% endblock %}
